@@ -50,6 +50,13 @@ mod _lib {
         Ok(closeness_centrality.unwrap())
     }
 
+    #[pyfunction]
+    fn clustering(graph: &Graph, weighted: bool) -> PyResult<HashMap<usize, f64>> {
+        let clustering_scores =
+            algorithms::cluster::clustering(&graph.graph, weighted, None).unwrap();
+        Ok(clustering_scores)
+    }
+
     #[pyfunction]
     fn constraint(graph: &Graph, weighted: bool) -> PyResult<HashMap<usize, f64>> {
         let constraints =
@@ -65,4 +72,11 @@ mod _lib {
         Ok(eigenvector_centrality.unwrap())
     }
 
+    #[pyfunction]
+    fn spectral_gap(graph: &Graph, weighted: bool) -> PyResult<f64> {
+        let sg =
+            algorithms::resiliency::spectral_gap::spectral_gap(&graph.graph, weighted).unwrap();
+        Ok(sg)
+    }
+
 }
